@@ -12,4 +12,4 @@ class Pingmeen:
         
     def __server_query(self, method):
         url = 'http://2kolobka.pro/nikita/pingmeen/'
-        return requests.get(url + method + '.php?token' + self.token).text
\ No newline at end of file
+        return requests.get(url + method + '.php?token=' + self.token).text
\ No newline at end of file
